@@ -48,8 +48,12 @@ class Spotify(object):
         endpoint += '&%s=%s' % (item, json_data[item])
       else:
         endpoint += '?%s=%s' % (item, json_data[item])
-        
-    response = await self.session.request(method, endpoint, headers=authorization)
+
+    try: 
+      json = kwargs['json']
+    except: 
+      json = None 
+    response = await self.session.request(method, endpoint, headers=authorization, json=json)
 
     if response.status in self.error_codes:
       return False
@@ -98,15 +102,6 @@ class Spotify(object):
 
     return path
 
-
-  async def refresh_token(self, refresh_token):
-    payload = {
-      'grant_type': 'refresh_token',
-      'refresh_token': refresh_token
-    }
-
-    return await self.send_request('POST', 'https://accounts.spotify.com/api/token', payload)
-  
   async def get_token(self, code):
     payload = {
       'grant_type': 'authorization_code',
@@ -181,6 +176,12 @@ class Spotify(object):
       items = [self.get_id('track', i) for i in ids]
     return await self.send_request('DELETE', 'https://api.spotify.com/v1/me/tracks', ids=','.join(items))
 
+  async def hearted(self, ids):
+    items = []
+    if ids != None:
+      items = [self.get_id('track', i) for i in ids]
+    return await self.send_request('GET', 'https://api.spotify.com/v1/me/tracks/contains', ids=','.join(items))
+
   async def search(self, query, limit=10, offset=0, type='track'):
     if not type in ('track', 'artist', 'album', 'playlist'):
       return False
@@ -216,6 +217,12 @@ class Spotify(object):
     items = [self.get_uri('track', i) for i in items]
     return await self.send_request('POST', 'https://api.spotify.com/v1/playlists/%s/tracks' % id, uris=','.join(items), position=position)
 
+  async def playlist_remove(self, id, items):
+    id = self.get_id('playlist', id)
+    items = [self.get_uri('track', i) for i in items]
+    data = dict(tracks=[{'uri': i} for i in items])
+    return await self.send_request('DELETE', 'https://api.spotify.com/v1/playlists/%s/tracks' % id, json=data)
+
   async def queue(self, track, device=None):
     uri = self.get_uri('track', track)
 
@@ -257,10 +264,6 @@ class Spotify(object):
   async def devices(self):
     return await self.send_request('GET', 'https://api.spotify.com/v1/me/player/devices')
 
-  async def swap_device(self, device, force=True):
-    payload = {
-      'device_ids': [device],
-      'play': force
-    }
-
-    return await self.send_request('PUT', 'https://api.spotify.com/v1/me/player', payload=payload)
+  async def swap_device(self, device):
+    data = dict(device_ids=[device])
+    return await self.send_request('PUT', 'https://api.spotify.com/v1/me/player', json=data)
